#!/usr/bin/python
# -*- coding: utf-8 -*-
# vim: ts=4
###
#
# gmixer is the legal property of mehdi abaakouk <theli48@gmail.com>
# Copyright (c) 2008 Mehdi Abaakouk
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
#
###

import os
import glob
from distutils.command.build_ext import build_ext as _build_ext
from distutils.core import setup, Extension

class build_ext(_build_ext):
    def run(self):
        os.system('make -C volkeys volkeyspy.c')
        _build_ext.run(self)

langs = [ "fr" ]
translations = [ ]
for lang in langs:
    translations.append (("share/locale/%s/LC_MESSAGES" % lang,
    ["po/%s/LC_MESSAGES/gmixer.mo" % lang]))

def capture(cmd): return os.popen(cmd).read().strip()

def rmgeneric(path, __func__):
    try:
        __func__(path)
    except OSError, (errno, strerror):
        pass

def removeall(path):
    if not os.path.isdir(path):
        return

    files=os.listdir(path)

    for x in files:
        fullpath=os.path.join(path, x)
        if os.path.isfile(fullpath):
            f=os.remove
            rmgeneric(fullpath, f)
        elif os.path.isdir(fullpath):
            removeall(fullpath)
            f=os.rmdir
            rmgeneric(fullpath, f)

setup(cmdclass={'build_ext': build_ext},
      name='gmixer',
      version='1.0',
      maintainer="ABAAKOUK Mehdi",
      maintainer_email="theli48@gmail.com",
      url = "http://www.listen-project.org/",
      license = "http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt",
      scripts=['src/gmixer'],
      packages=[''],
      package_dir={'': 'src'},
      package_data={'': ["gtktrayicon.py"]},
      data_files=[ ('share/gmixer', glob.glob('data/*.png')+ glob.glob("data/*.glade")) ] + translations,
      ext_modules=[
         Extension("volkeys",
                   ["volkeys/volkeyspy.c", "volkeys/volkeys.c", "volkeys/volkeysmodule.c"],
                   extra_compile_args = capture("pkg-config --cflags gtk+-2.0 pygtk-2.0").split(),
                   extra_link_args = capture("pkg-config --libs gtk+-2.0 pygtk-2.0").split()
                   ),
                ],
      )
# Cleanup (remove /build, /mo, and *.pyc files:
print "Cleaning up..."
try:
    removeall("build/")
    os.rmdir("build/")
except:
    pass
try:
    removeall("dist/")
    os.rmdir("dist/")
except:
    pass
try:
    os.system('make -C volkeys clean')
except: 
    pass
try:
    for f in os.listdir("src/"):
        f = os.path.join("src",f)
        if os.path.isfile(f):
            if os.path.splitext(os.path.basename(f))[1] in [".pyc", ".pyo"]:
                os.remove(f)
except:
    pass

